@@ -211,7 +211,9 @@ class PreseemModel:
                     continue
                 stubcls = stubs[0]
                 svcstub = getattr(gmod, stubcls)(self._client._channel)
-                svcname = stubcls[:-11]  # trim "ServiceStub" from the name
+                svcname = stubcls[:-11] if stubcls.endswith(
+                    'ServiceStub') else stubcls[:-7] if stubcls.endswith(
+                        'ApiStub') else stubcls  # trim "ServiceStub" from the name
 
                 # Create a new python class for this model object type
                 cls = type(svcname, (BaseModelObject, ), {})
